[SCM] WebKit Debian packaging branch, debian/experimental, updated. upstream/1.3.3-9427-gc2be6fc

commit-queue at webkit.org commit-queue at webkit.org
Wed Dec 22 11:23:39 UTC 2010


The following commit has been merged in the debian/experimental branch:
commit 2f27413339717cc7bddde22c955c664c9fa7cfaf
Author: commit-queue at webkit.org <commit-queue at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Wed Jul 21 17:44:36 2010 +0000

    2010-07-21  Finnur Thorarinsson  <finnur.webkit at gmail.com>
    
            Reviewed by Dimitri Glazkov.
    
            Avoid crashing during find-in-page when |view| is NULL.
            https://bugs.webkit.org/show_bug.cgi?id=42760
    
            There are no layout tests because we don't have a repro case
            to work with, so this is a speculative fix based on crash dump
            diagnosis. See bug for details.
    
            * src/WebFrameImpl.cpp:
            (WebKit::WebFrameImpl::shouldScopeMatches):
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@63841 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/chromium/ChangeLog b/WebKit/chromium/ChangeLog
index 297036b..e9a1111 100644
--- a/WebKit/chromium/ChangeLog
+++ b/WebKit/chromium/ChangeLog
@@ -1,3 +1,17 @@
+2010-07-21  Finnur Thorarinsson  <finnur.webkit at gmail.com>
+
+        Reviewed by Dimitri Glazkov.
+
+        Avoid crashing during find-in-page when |view| is NULL.
+        https://bugs.webkit.org/show_bug.cgi?id=42760
+        
+        There are no layout tests because we don't have a repro case
+        to work with, so this is a speculative fix based on crash dump
+        diagnosis. See bug for details.
+
+        * src/WebFrameImpl.cpp:
+        (WebKit::WebFrameImpl::shouldScopeMatches):
+
 2010-07-21  Hans Wennborg  <hans at chromium.org>
 
         Reviewed by Steve Block.
diff --git a/WebKit/chromium/src/WebFrameImpl.cpp b/WebKit/chromium/src/WebFrameImpl.cpp
index 535d128..f1c30e2 100644
--- a/WebKit/chromium/src/WebFrameImpl.cpp
+++ b/WebKit/chromium/src/WebFrameImpl.cpp
@@ -2101,9 +2101,9 @@ int WebFrameImpl::ordinalOfFirstMatchForFrame(WebFrameImpl* frame) const
 
 bool WebFrameImpl::shouldScopeMatches(const String& searchText)
 {
     // Don't scope if we can't find a frame or if the frame is not visible.
     // The user may have closed the tab/application, so abort.
-    if (!frame() || !hasVisibleContent())
+    if (!frame() || !frame()->view() || !hasVisibleContent())
         return false;
 
     ASSERT(frame()->document() && frame()->view());
@@ -2101,9 +2101,9 @@ int WebFrameImpl::ordinalOfFirstMatchForFrame(WebFrameImpl* frame) const
 bool WebFrameImpl::shouldScopeMatches(const String& searchText)
 {
-    // Don't scope if we can't find a frame or if the frame is not visible.
+    // Don't scope if we can't find a frame or a view or if the frame is not visible.
     // The user may have closed the tab/application, so abort.

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list